function s = spider_trace_unequal_arms(et, shift, delay, rel_inten)

% Calculates the theoretical ideal SPIDER trace for a given input electric
% field, frequency shear, and delay, with some intensity mismatch between
% pulse replicas

% et is the electric field, and it should be a function of time.
%
% shear is the frequency shear between pulse replicas, and it has units 
% of 2*pi/[(number of points)*(temporal resolution)].
%
% delay is the temporal delay between pulse replicas.
%
% rel_inten is the ratio of the intensity of the sheared pulse to the
% unsheared pulse

rel_amp = sqrt(rel_inten);
et = et(:);
n = length(et);
ew = 1/sqrt(n)*fftc(et);
et_shear = circshift(et, delay);
ew_shear = 1/sqrt(n)*fftc(et_shear);
ew_dw = circshift(ew_shear, shift);

s = abs(ew + rel_amp*ew_dw).^2;